#ifndef F_DRAW
#define F_DRAW

#include "../global.h"
#include "../FrameRender/PixelCallback.h"
#include "FrameCallback.h"

typedef struct Draw {
	const PixelCallback** callbacks;
	usize sizeCallbacks;
} Draw;

FrameCallback* Draw_setup(Draw obj);

#endif /* F_DRAW */
