#ifndef _ANIMATION_RENDER
#define _ANIMATION_RENDER

#include "../global.h"
#include "FrameCallback.h"

void RenderAnimation(u32 width, u32 height, u32 totalFrames, const FrameCallback** callbacks, usize sizeCallbacks);

#endif /* _ANIMATION_RENDER */
