#ifndef P_TRANSFORMROTATE
#define P_TRANSFORMROTATE

#include "PixelCallback.h"
#include "../global.h"

typedef struct TransformRotate {
	double angle;
} TransformRotate;

PixelCallback* TransformRotate_setup(TransformRotate obj);

#endif /* P_TRANSFORMROTATE */
