#ifndef P_LINE_SEGMENT
#define P_LINE_SEGMENT

#include "PixelCallback.h"

typedef struct LineSegment {
	i32 aX;
	i32 aY;
	i32 bX;
	i32 bY;
	u32 width;
	color color;
} LineSegment;

PixelCallback* LineSegment_setup(LineSegment obj);

#endif /* P_LINE_SEGMENT */
